@@ -134,9 +134,15 @@ def prepare_crispr_shrinkage_visualization_input(crispr_shrinkage_result: Crispr
 
     return crispr_shrinkage_visualization_input
 
-def normalize_shape_size(input_shape_sizes: List[Union[int,float]], max_shape_size: Union[int,float]):
+def normalize_shape_size(input_shape_sizes: List[Union[int,float]], max_shape_size: Union[int,float], all_shape_sizes: Union[List[Union[int,float]], None] = None):
     input_shape_sizes = np.asarray(input_shape_sizes)
-    return ((input_shape_sizes - input_shape_sizes.min()) / (input_shape_sizes.max() - input_shape_sizes.min())) * max_shape_size
+    if all_shape_sizes is None:
+        all_shape_sizes = input_shape_sizes
+    else:
+        all_shape_sizes = np.asarray(all_shape_sizes)
+        
+    return ((input_shape_sizes - all_shape_sizes.min()) / (all_shape_sizes.max() - all_shape_sizes.min())) * max_shape_size
+
 
 def visualize_lfc_histogram(crispr_shrinkage_visualization_input: CrisprShrinkageVisualizationInput):
     plt.hist(crispr_shrinkage_visualization_input.negative_control_lfc, density=True, label="Negative")
@@ -180,10 +186,10 @@ def visualize_raw_vs_adjusted_score_scatter(crispr_shrinkage_visualization_input
 
 def visualize_raw_and_adjusted_score_by_position_scatter(crispr_shrinkage_visualization_input: CrisprShrinkageVisualizationInput, max_shape_size = 10):
     for rep_i in crispr_shrinkage_visualization_input.replicate_indices:
-        plt.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc_rep[rep_i], s=normalize_shape_size(crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size))
+        plt.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc_rep[rep_i], s=normalize_shape_size(input_shape_sizes=crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size=max_shape_size))
         plt.title("Adjusted LFC")
         plt.show()
-        plt.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_raw_lfc_rep[rep_i], s=normalize_shape_size(crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size))
+        plt.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_raw_lfc_rep[rep_i], s=normalize_shape_size(input_shape_sizes=crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size=max_shape_size))
         plt.title("Raw LFC")
         plt.show()
 
@@ -200,7 +206,7 @@ def visualize_combined_adjusted_score_by_position_scatter(crispr_shrinkage_visua
     ax = fig.add_subplot(111)
 
     for rep_i in crispr_shrinkage_visualization_input.replicate_indices:
-        ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc_rep[rep_i], s=normalize_shape_size(crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size), alpha=0.3, label="Replicate {}".format(rep_i))
+        ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc_rep[rep_i], s=normalize_shape_size(input_shape_sizes=crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size=max_shape_size), alpha=0.3, label="Replicate {}".format(rep_i))
     ax.scatter(explanatory_positions, explanatory_lfc, marker="s", s=2, label="Combined")
     ax.plot(explanatory_positions, explanatory_lfc, color="red", alpha=0.2)
     ax.set_title("Region Scores")
@@ -245,8 +251,8 @@ def visualize_all_adjusted_score_credible_interval_by_position_scatter(crispr_sh
         explanatory_lfc_rep_rep_standardized = stats.zscore(crispr_shrinkage_visualization_input.explanatory_lfc_rep[rep_i])
         explanatory_raw_lfc_rep_standardized = stats.zscore(crispr_shrinkage_visualization_input.explanatory_raw_lfc_rep[rep_i])
 
-        ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions,explanatory_lfc_rep_rep_standardized, s=normalize_shape_size(crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size), color="blue", alpha=0.85, label="Adjusted")
-        ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions,explanatory_raw_lfc_rep_standardized, s=normalize_shape_size(crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size), color="black", alpha=0.85, label="Raw") # Can color based on which of the guides are in the observational set and which are not (specifically which are in the positive, negative.
+        ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions,explanatory_lfc_rep_rep_standardized, s=normalize_shape_size(input_shape_sizes=crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size=max_shape_size), color="blue", alpha=0.85, label="Adjusted")
+        ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions,explanatory_raw_lfc_rep_standardized, s=normalize_shape_size(input_shape_sizes=crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size=max_shape_size), color="black", alpha=0.85, label="Raw") # Can color based on which of the guides are in the observational set and which are not (specifically which are in the positive, negative.
         for guide_i in range(len(crispr_shrinkage_visualization_input.explanatory_positions)):
             ax.arrow(crispr_shrinkage_visualization_input.explanatory_positions[guide_i], explanatory_raw_lfc_rep_standardized[guide_i],0, explanatory_lfc_rep_rep_standardized[guide_i] - explanatory_raw_lfc_rep_standardized[guide_i], head_width=1, head_length=0.2, alpha=0.4, length_includes_head=True, color="black")
 
@@ -265,7 +271,7 @@ def visualize_standardized_adjusted_score_by_position_scatter(crispr_shrinkage_v
     ax = fig.add_subplot(111)
 
     for rep_i in crispr_shrinkage_visualization_input.replicate_indices:
-        ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc_rep[rep_i], s=normalize_shape_size(crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size), alpha=0.3, label="Replicate {}".format(rep_i))
+        ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc_rep[rep_i], s=normalize_shape_size(input_shape_sizes=crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], max_shape_size=max_shape_size), alpha=0.3, label="Replicate {}".format(rep_i))
     ax.scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc, marker="s",color="black", s=10, label="Combined")
     ax.errorbar(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc, (crispr_shrinkage_visualization_input.explanatory_lfc-explanatory_lfc_CI_low, explanatory_lfc_CI_up-crispr_shrinkage_visualization_input.explanatory_lfc), solid_capstyle='projecting', capsize=1, alpha=0.3, linestyle='')
 
@@ -285,5 +291,29 @@ def visualize_all(crispr_shrinkage_visualization_input: CrisprShrinkageVisualiza
     visualize_all_adjusted_score_credible_interval_by_position_scatter(crispr_shrinkage_visualization_input, max_shape_size)
     visualize_standardized_adjusted_score_by_position_scatter(crispr_shrinkage_visualization_input, max_shape_size)
 
+def visualize_raw_and_adjusted_score_by_position_scatter_multiple(crispr_shrinkage_visualization_input_list: List[CrisprShrinkageVisualizationInput], input_label_list: List[str], max_shape_size = 10):
+    assert len(crispr_shrinkage_visualization_input_list) > 0, "Input list must be greater than 0"
+    assert len(crispr_shrinkage_visualization_input_list) == len(input_label_list), "Label list must be the same size as the input list"
+    
+    for rep_i in crispr_shrinkage_visualization_input_list[0].replicate_indices:
+        fig, axs = plt.subplots(2, 1, figsize=(20, 4*len(crispr_shrinkage_visualization_input_list)))
+        for input_index in range(len(crispr_shrinkage_visualization_input_list)):
+            crispr_shrinkage_visualization_input = crispr_shrinkage_visualization_input_list[input_index]
+            input_label = input_label_list[input_index] 
+            
+            normalized_count = normalize_shape_size(input_shape_sizes=crispr_shrinkage_visualization_input.explanatory_count_rep[rep_i], all_shape_sizes=np.concatenate([crispr_shrinkage_visualization_input_i.explanatory_count_rep[rep_i] for crispr_shrinkage_visualization_input_i in crispr_shrinkage_visualization_input_list]), max_shape_size=max_shape_size)
+            axs[0].scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_lfc_rep[rep_i], s=normalized_count, label=input_label)
+            axs[0].set_title("Adjusted LFC")
+            
+            axs[1].scatter(crispr_shrinkage_visualization_input.explanatory_positions, crispr_shrinkage_visualization_input.explanatory_raw_lfc_rep[rep_i], s=normalized_count, label=input_label)
+            axs[1].set_title("Raw LFC")
+            axs[1].set_label(input_label)
+        axs[0].legend()
+        axs[1].legend()
+        
+        fig.suptitle("Replicate: {}".format(rep_i+1))
+        plt.show()
+
+
 def prepare_reporting_df(crispr_shrinkage_visualization_input: CrisprShrinkageVisualizationInput):
     pass
\ No newline at end of file
